@@ -1,8 +1,6 @@
 import argparse
 from time import sleep
-from typing import Dict
-
-import pandas as pd
+from typing import Dict, List
 
 from xklb import db
 from xklb.player import generic_player, mark_media_watched, override_sort, printer
@@ -87,7 +85,7 @@ def play(args, m: Dict):
     mark_media_watched(args, media_file)
 
 
-def frequency_filter(args, media: pd.DataFrame):
+def frequency_filter(args, media: List[Dict]):
     mapper = {
         Frequency.Daily.value: 1,
         Frequency.Weekly.value: 7,
@@ -96,15 +94,20 @@ def frequency_filter(args, media: pd.DataFrame):
         Frequency.Yearly.value: 365,
     }
     counts = args.db.execute("select frequency, count(*) from media group by 1").fetchall()
+    filtered_media = []
     for freq, freq_count in counts:
         num_days = mapper.get(freq, 365)
         num_tabs = max(1, freq_count // num_days)
         log.debug(f"freq_count {freq_count} // num_days {num_days} = num_tabs {num_tabs}")
 
-        media[media.frequency == freq] = media[media.frequency == freq].head(num_tabs)
-        media.dropna(inplace=True)
+        t = []
+        for m in media:
+            if m["frequency"] == freq:
+                t.append(m)
 
-    return media
+        filtered_media.extend(t[:num_tabs])
+
+    return filtered_media
 
 
 def process_tabs_actions(args, construct_tabs_query):
@@ -114,14 +117,14 @@ def process_tabs_actions(args, construct_tabs_query):
     if args.print:
         return printer(args, query, bindings)
 
-    media = pd.DataFrame(args.db.query(query, bindings))  # type: ignore
+    media = list(args.db.query(query, bindings))  # type: ignore
     if len(media) == 0:
         print("No media found")
         exit(2)
 
     media = frequency_filter(args, media)
 
-    for m in media.to_records():
+    for m in media:
         play(args, m)
     if len(media) > 10:
         sleep(0.3)
@@ -169,6 +172,33 @@ def parse_args(action, default_db):
         ╞═══════════╪═════════╡
         │ Aggregate │     134 │
         ╘═══════════╧═════════╛
+
+    Delete URLs
+
+        lb tb -p -s cyber
+        ╒═══════════════════════════════════════╤═════════════╤══════════════╕
+        │ path                                  │ frequency   │ time_valid   │
+        ╞═══════════════════════════════════════╪═════════════╪══════════════╡
+        │ https://old.reddit.com/r/cyberDeck/to │ yearly      │ Dec 31 1970  │
+        │ p/?sort=top&t=year                    │             │              │
+        ├───────────────────────────────────────┼─────────────┼──────────────┤
+        │ https://old.reddit.com/r/Cyberpunk/to │ yearly      │ Aug 29 2023  │
+        │ p/?sort=top&t=year                    │             │              │
+        ├───────────────────────────────────────┼─────────────┼──────────────┤
+        │ https://www.reddit.com/r/cyberDeck/   │ yearly      │ Sep 05 2023  │
+        ╘═══════════════════════════════════════╧═════════════╧══════════════╛
+        lb tb -p -w "path='https://www.reddit.com/r/cyberDeck/'" --delete
+        Removed 1 metadata records
+        lb tb -p -s cyber
+        ╒═══════════════════════════════════════╤═════════════╤══════════════╕
+        │ path                                  │ frequency   │ time_valid   │
+        ╞═══════════════════════════════════════╪═════════════╪══════════════╡
+        │ https://old.reddit.com/r/cyberDeck/to │ yearly      │ Dec 31 1970  │
+        │ p/?sort=top&t=year                    │             │              │
+        ├───────────────────────────────────────┼─────────────┼──────────────┤
+        │ https://old.reddit.com/r/Cyberpunk/to │ yearly      │ Aug 29 2023  │
+        │ p/?sort=top&t=year                    │             │              │
+        ╘═══════════════════════════════════════╧═════════════╧══════════════╛
 """,
     )
     parser.add_argument(
@@ -184,6 +214,7 @@ def parse_args(action, default_db):
     parser.add_argument("--exclude", "-E", "-e", nargs="+", action="extend", default=[])
 
     parser.add_argument("--print", "-p", default=False, const="p", nargs="?")
+    parser.add_argument("--delete", "--remove", "--erase", "--rm", "-rm", action="store_true", help=argparse.SUPPRESS)
     parser.add_argument("--cols", "-cols", "-col", nargs="*", help="Include a non-standard column when printing")
     parser.add_argument("--limit", "-L", "-l", "-queue", "--queue")
     parser.add_argument("--skip", "-S")
@@ -203,6 +234,9 @@ def parse_args(action, default_db):
     if args.cols:
         args.cols = list(flatten([s.split(",") for s in args.cols]))
 
+    if args.delete:
+        args.print += "d"
+
     log.info(dict_filter_bool(args.__dict__))
 
     return args
