@@ -3,15 +3,13 @@ from datetime import datetime
 from pathlib import Path
 from urllib.parse import urlparse
 
-import pandas as pd
-
 from xklb import db, utils
 from xklb.paths import Frequency, sanitize_url
 from xklb.player import remove_media
 from xklb.utils import argparse_enum, log
 
 
-def parse_args():
+def parse_args_tabsadd():
     parser = argparse.ArgumentParser(
         prog="lb tabsadd",
         usage=r"""lb tabsadd --frequency {daily,weekly,monthly,quarterly,yearly} --category CATEGORY [--no-sanitize] [database] paths ...
@@ -47,7 +45,7 @@ def parse_args():
         help=argparse.SUPPRESS,
     )
     parser.add_argument("--category", "-c", help=argparse.SUPPRESS)
-    parser.add_argument("--no-sanitize", "-s", action="store_false", help="Don't sanitize some common URL parameters")
+    parser.add_argument("--no-sanitize", "-s", action="store_true", help="Don't sanitize some common URL parameters")
 
     parser.add_argument("-v", "--verbose", action="count", default=0)
     args = parser.parse_args()
@@ -108,14 +106,9 @@ def extract_url_metadata(args, path):
 def tabs_add(args=None):
     if args:
         sys.argv[1:] = args
-    args = parse_args()
+    args = parse_args_tabsadd()
 
-    tabsDF = pd.DataFrame([extract_url_metadata(args, path) for path in get_new_paths(args)])
-    tabsDF.apply(pd.to_numeric, errors="ignore").convert_dtypes().to_sql(  # type: ignore
-        "media",
-        con=args.db.conn,
-        if_exists="append",
-        index=False,
-        chunksize=70,
-        method="multi",
-    )
+    args.db = db.connect(args)
+    tabs = [extract_url_metadata(args, path) for path in get_new_paths(args)]
+
+    args.db["media"].insert_all(tabs, alter=True)  # type: ignore
